/*************************************************
 * ftp.h for SmartHome
 * Sina Karimi, Ryan Campbell, Hector Nunez
 * Feb, 2010
 *
 *************************************************/

#ifndef _FTP_H
#define _FTP_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

extern "C"
{
#include "parts/m55800/lib_m55800.h"
#include "parts/m55800/eb55.h"
#include "periph/ebi/lib_ebi.h"

#include "types.h"
#include "w5300.h"
#include "socket.h"

#include "os_cpu.h"
#include "ucos_ii.h"
    
#include "globals.h"
}


/* RESULT SET */
#define RESULT 			int
#define FTP_SUCCESS		0
#define FTP_READY_FAILED	51
#define FTP_USER_FAILED		52
#define FTP_PASS_FAILED		53
#define FTP_PASV_FAILED		54
#define FTP_OPEN_FAILED		55
#define FTP_DSOCK_CREATED	56
#define FTP_PORT_FAILED		57
/* end RESULT SET */

#define FTP_PORT		21
#define FTP_CTRL_SOCKET_HTTP	4
#define FTP_DATA_SOCKET_HTTP	5
#define FTP_CTRL_SOCKET_CAMERA	6
#define FTP_DATA_SOCKET_CAMERA	7


// FTP STATUS CODES
#define FTP_READY		220
#define FTP_PASV		227
#define FTP_PASS		331
#define FTP_LOGIN		230
#define FTP_OPENING		150
#define FTP_OPENFAILED 		550
#define FTP_PORT_SUCCESS 	200
#define FTP_OK_TO_SEND		150 /* yes, it's supposed to be the same as FTP_OPENING */
#define FTP_UNKNOWN		-1


#define FTP_MAXBUFF	128
#define CMD_LEN		64

/* connection types */
#define FTP_ACTIVE	0
#define FTP_PASSIVE	1

/*ftp_open flags */
#define READ	0
#define WRITE	1
#define APPEND	2
#define LIST	3

class FTP_Client;

class FTP_Client {

protected:
    //*----------------------------------------------------------------------------
    //* Function Name    :	send_ftpcmd
    //* Object           :	
    //*
    //* Input Parameters :	socket, the ftp socket
    //*			  	cmd, the command to be sent
    //*			  	data, the return data. if no needed pass NULL
    //*
    //* Output Parameters:	ftp status code
    //*----------------------------------------------------------------------------
    int send_ftpcmd(int socket, char * cmd, char * data);

    int wait_status_c(int sock, int status, uint8* ip, uint16* client_port, int server_port);

    
public:
    FTP_Client();
    
    //*----------------------------------------------------------------------------
    //* Function Name	 :	ftp_open
    //* Object		 :
    //*
    //* Input Parameters :	ctrl_sock, ftp control connection socket
    //*			  	data_sock, ftp data connection socket
    //*			 	filepath, the file path on the ftp server
    //*			 	con_type, PASSIVE OR ACTIVE
    //*			 	flag, READ OR WRITE
    //*
    //* Output Parameters:	FTP RESULT
    //*			  	ftp_status_code
    //*----------------------------------------------------------------------------
    RESULT ftp_open(int ctrl_sock, int data_sock, char * filepath, int con_type, int flag);

    //*----------------------------------------------------------------------------
    //* Function Name       : get_dir_list
    //* Object              : 
    //* Input Parameters    : 
    //*			  
    //*			  
    //*
    //* Output Parameters   : none
    //*----------------------------------------------------------------------------
    void get_dir_list(int ftp_ctrl_s, int ftp_data_s, char * dir_path,
	    char * buffer);


    int get_last_image_num(int ftp_ctrl_s, int ftp_data_s,
	    char * dir_path);
};

#endif /* FTP_H */
