/*************************************************
 * httpd.h for SmartHome
 * Sina Karimi, Ryan Campbell, Hector Nunez
 * Feb, 2010
 *
 *************************************************/

#ifndef _HTTPD_H
#define _HTTPD_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

extern "C"
{
#include "parts/m55800/lib_m55800.h"
#include "drivers/capture/capture.h"
#include "drivers/wait/wait.h"
#include "parts/m55800/eb55.h"
#include "periph/ebi/lib_ebi.h"
#include "types.h"
#include "w5300.h"
#include "socket.h"
#include "globals.h"
}

#include "ftp.h"
#include "camera.h"

#define HTTP_PORT 		80
#define BUFFSIZE		4000
#define PROTOCOL 		"HTTP/1.0"
#define MAX_HTTP_SOCK		4

/* HTTP status codes */
#define HTTP_OK                 200
#define HTTP_NOT_FOUND          404
#define HTTP_BAD_REQUEST        400
#define HTTP_NOT_IMPLEMENTED    501

#define IMAGE_DIR "SmartHome/www/img/"

extern Camera camera;
extern FTP_Client ftp_client;

class Httpd;

class Httpd {

protected:

    //TODO LATER
    //int ftp_ctrl_s = FTP_CTRL_SOCKET_HTTP;
    //int ftp_data_s = FTP_DATA_SOCKET_HTTP;

    //*----------------------------------------------------------------------------
    //* Function Name       : handle_client
    //* Object              : 
    //* Input Parameters    : socket, http socket
    //*			  ftp_ctrl_s, ftp control connection socket
    //*			  ftp_data_s, ftp data connection socket
    //*
    //* Output Parameters   : 0 on success and 1 on error.
    //*----------------------------------------------------------------------------
    int handle_client(int socket, int ftp_ctrl_s, int ftp_data_s);
    

    
    //*----------------------------------------------------------------------------
    //* Function Name       : parse_list
    //* Object              : 
    //* Input Parameters    : 
    //*			  
    //*			  
    //*
    //* Output Parameters   : none
    //*----------------------------------------------------------------------------
    void parse_list(char * unparsed, char * parsed);
 
    //*----------------------------------------------------------------------------
    //* Function Name       : send_status
    //* Object              : 
    //* Input Parameters    : socket, http socket
    //*			  status, error status code
    //*			  desc, error description
    //*
    //* Output Parameters   : none
    //*----------------------------------------------------------------------------
    void send_status(int socket, int status, char* desc);
    
    
    //*----------------------------------------------------------------------------
    //* Function Name       : send_header
    //* Object              : 
    //* Input Parameters    : socket, http socket
    //*			  status,
    //*			  desc,
    //*			  mime_type,
    //*
    //* Output Parameters   : none
    //*----------------------------------------------------------------------------
    void send_header(int socket, int status, char* desc, char *mime_type);
    
    
    //*----------------------------------------------------------------------------
    //* Function Name       : get_mimetype
    //* Object              : 
    //* Input Parameters    : path, URL that was sent by client
    //* Output Parameters   : type of the file requested, i.e.: text/html
    //*----------------------------------------------------------------------------
    char * get_mimetype(char * path);

    void send_dir_list(int http_s, int ftp_ctrl_s, int ftp_data_s,
	    char * dir_path);

    void decode_send(int http_s, int ftp_data_s);

    void callFunction(char * fnName, char * fnReturn);

    void getName(char * fnReturn);

    void getImgArray(char * fnReturn);
    
public:

    Httpd();
    
    //*----------------------------------------------------------------------------
    //* Function Name       : httpd_server_run
    //* Object              : 
    //*  Input Parameters    : none
    //* Output Parameters   : none
    //*----------------------------------------------------------------------------
    void run();

};

#endif /* HTTPD_H */
