/*************************************************
 * ftp.c for SmartHome
 * Sina Karimi, Ryan Campbell, Hector Nunez
 * Feb, 2010
 *
 *************************************************/

#include "ftp.h"

/* opens up an ftp connection to 192.168.10.101
 *
 * returns the socket to be used for the FTP data connection,
 * which the user can then recv from.
 *
 * NOTE: READ ONLY FOR NOW
 */

FTP_Client::FTP_Client()
{
    
}

RESULT FTP_Client::ftp_open(int ctrl_sock, int data_sock, char * filepath, int con_type, int flag)
{
    int ret, port, port1, port2;
    char buffer[FTP_MAXBUFF + 1];
    char cmd[CMD_LEN + 1];
   
    
    uint8 serverip[4] = {192,168,10,101};
    uint16 any_port = 1000;
    
    at91_pio_write (&PIOB_DESC, LED2, LED_OFF);
    at91_pio_write (&PIOB_DESC, LED2, LED_ON );
  
    memset(buffer, 0, FTP_MAXBUFF + 1);
    memset(cmd, 0, CMD_LEN + 1);
    
    socket(ctrl_sock, Sn_MR_TCP, any_port++, 0);
    connect(ctrl_sock, serverip, FTP_PORT);

    wait_status_c(ctrl_sock, SOCK_ESTABLISHED, serverip, &any_port, FTP_PORT);


    if(getSn_IR(ctrl_sock) & Sn_IR_CON)      // check Sn_IR_CON bit
	    setSn_IR(ctrl_sock,Sn_IR_CON);        // clear Sn_IR_CON

    ret = recv(ctrl_sock, (uint8 *)buffer, FTP_MAXBUFF);
    if (ret > 0 && ret < FTP_MAXBUFF)
	    buffer[ret] = 0;

    if (sscanf(buffer, "%d", &ret) != 1 || ret != FTP_READY)
	return FTP_READY_FAILED;

    if (send_ftpcmd(ctrl_sock, "USER default\r\n", NULL) != FTP_PASS)
	return FTP_USER_FAILED;

    if (send_ftpcmd(ctrl_sock, "PASS qwe123\r\n", NULL) != FTP_LOGIN)
	return FTP_PASS_FAILED;

    at91_pio_write (&PIOB_DESC, LED3, LED_OFF);
    at91_pio_write (&PIOB_DESC, LED3, LED_ON );

    if (con_type == FTP_PASSIVE)
    {
	if (send_ftpcmd(ctrl_sock, "PASV\r\n", buffer) != FTP_PASV)
	    return FTP_PASV_FAILED;
    
	sscanf (buffer, "227 Entering Passive Mode (192,168,10,101,%d,%d).",
	    &port1, &port2);

	port = port2 + (port1 * 256);

	socket(data_sock, Sn_MR_TCP, any_port++, 0);
	connect(data_sock, serverip, port);
    }
    else if (con_type == FTP_ACTIVE)
    {
	port1 = 60;
	port2 = 12;
	port = port1*256 + port2;

	disconnect(data_sock);
	close(data_sock);
	
	
	socket(data_sock, Sn_MR_TCP, port, 0);
	listen(data_sock);
 
	sprintf(cmd, "PORT 192,168,10,100,%d,%d\r\n", port1, port2);
	if(send_ftpcmd(ctrl_sock, cmd, buffer) != FTP_PORT_SUCCESS)
	    return FTP_PORT_FAILED;
    }

    if(flag == READ)
    {
	sprintf(cmd, "RETR %s\r\n", filepath);
	if(send_ftpcmd(ctrl_sock, cmd, NULL) != FTP_OPENING)
	    return FTP_OPEN_FAILED;
    }
    else if(flag == WRITE)
    {
	sprintf(cmd, "STOR %s\r\n", filepath);
	if(send_ftpcmd(ctrl_sock, cmd, NULL) != FTP_OK_TO_SEND)
	    return FTP_OPEN_FAILED;
    }
    else if(flag == APPEND)
    {
	sprintf(cmd, "APPE %s\r\n", filepath);
	if(send_ftpcmd(ctrl_sock, cmd, NULL) != FTP_OK_TO_SEND)
	    return FTP_OPEN_FAILED;
    }
    else if (flag == LIST)
    {
	sprintf(cmd, "NLST %s\r\n", filepath);
	if(send_ftpcmd(ctrl_sock, cmd, NULL) != FTP_OK_TO_SEND)
	    return FTP_OPEN_FAILED;
    }
    
    at91_pio_write (&PIOB_DESC, LED3, LED_OFF);
    at91_pio_write (&PIOB_DESC, LED2, LED_OFF);
  
    return FTP_SUCCESS;

} /* ftp_open */

int FTP_Client::get_last_image_num(int ftp_ctrl_s, int ftp_data_s,
	char * dir_path)
{
    char buff[1024];
    
    int img_num;
    char * slash_pos;
    
    get_dir_list(ftp_ctrl_s, ftp_data_s, dir_path, buff);

    slash_pos = strrchr(buff, '/');
    if (slash_pos == NULL)
	img_num = -1;
    else
	sscanf(slash_pos+1, "image%d.jpg", &img_num);

    return img_num;
  
  
    
}

void FTP_Client::get_dir_list(int ftp_ctrl_s, int ftp_data_s, char * dir_path,
	char * buffer)
{
    int len;
 
    if(ftp_open(ftp_ctrl_s, ftp_data_s, dir_path, FTP_PASSIVE,
	    LIST) != FTP_SUCCESS)
    {
	//send_status(http_s, HTTP_NOT_FOUND, "Not Found");
	disconnect(ftp_data_s);
	close(ftp_data_s);
	disconnect(ftp_ctrl_s);
	close(ftp_ctrl_s);
	return;
    }

    len = getSn_RX_RSR(ftp_data_s);

    if (len > FTP_MAXBUFF-1)
	len = FTP_MAXBUFF;
    
    if (len != 0)
	recv(ftp_data_s, (uint8*)buffer, len);

    disconnect(ftp_data_s);
    close(ftp_data_s);
    disconnect(ftp_ctrl_s);
    close(ftp_ctrl_s);
    
    
}/* get_dir_list */

int FTP_Client::send_ftpcmd(int sock, char * cmd, char * data)
{
    char buff[FTP_MAXBUFF + 1];
    int ret, len;
    int status_code = FTP_UNKNOWN;

    memset(buff, 0, FTP_MAXBUFF+1);
#ifdef DEBUG
    printf("sending: %s", cmd);
#endif

    at91_pio_write (&PIOB_DESC, LED3, LED_ON);
    
    send_all(sock, (uint8 *)cmd, strlen(cmd));

    //OSTimeDly(OS_TICKS_PER_SEC);


    at91_pio_write (&PIOB_DESC, LED4, LED_ON);
    /* block until we have something to read) */
    while((len = getSn_RX_RSR(sock)) < 1)
    {
	at91_pio_write (&PIOB_DESC, LED5, LED_ON);
	
    }

   at91_pio_write (&PIOB_DESC, LED5, LED_OFF);
    
#ifdef DEBUG
    printf("len = %d\n", len);
#endif
    if( len > FTP_MAXBUFF)
	len = FTP_MAXBUFF;

    ret = recv(sock, (uint8 *)buff, len);
#ifdef DEBUG
    printf("ret = %d\n", ret);
#endif
    
    if (ret > 0 && ret < FTP_MAXBUFF)
	    buff[ret] = 0;
#ifdef DEBUG
    printf("buff = %s\n", buff);
#endif

    at91_pio_write (&PIOB_DESC, LED4, LED_OFF);
    
    if(sscanf(buff, "%d", &status_code) != 1)
    {
#ifdef DEBUG
	    printf("sscanf failed\n");
	    printf( "buffer = %s\n", buff);
#endif
    
    }
    else if (data != NULL)
    {
    	strcpy(data, buff);
    }

   at91_pio_write (&PIOB_DESC, LED3, LED_OFF);
    
    return status_code;

} /* send_ftpcmd */

int FTP_Client::wait_status_c(int sock, int status, uint8* ip, uint16* client_port, int server_port)
{
    int temp;
    int temp2 = -1;

    while((temp = getSn_SSR(sock)) != status){
	
	if (temp2 != temp) {
	    temp2 = temp;
#ifdef DEBUG
	    printf("Status is 0x%x\n", temp);
#endif
	    
	}

	if (temp == SOCK_CLOSED || temp == SOCK_CLOSE_WAIT){
	    /* the socket closed (timeout?). reconnect */
	    disconnect(sock);
	    close(sock);
	    OSTimeDly(OS_TICKS_PER_SEC);
	    socket(sock, Sn_MR_TCP, *(client_port)++, 0);
	    connect(sock, ip, server_port);

	}
    }/* while */

    return 0;
   
}/* wait_status_c */
