/*************************************************
 * httpd.c for SmartHome
 * Sina Karimi, Ryan Campbell, Hector Nunez
 * Feb, 2010
 *
 *************************************************/

#include "httpd.h"

extern "C"
{
    extern void c_handler();
}
Httpd::Httpd()
{

}

void Httpd::run()
{
    int i;
    int ftp_ctrl_s = FTP_CTRL_SOCKET_HTTP;
    int ftp_data_s = FTP_DATA_SOCKET_HTTP;

    for (i =0; i < MAX_HTTP_SOCK; i++)
    {
	
	switch(getSn_SSR(i))
	{
	    case SOCK_ESTABLISHED:
		if(getSn_IR(i) & Sn_IR_CON)
		    setSn_IR(i, Sn_IR_CON);
#ifdef DEBUG
		printf("accepted connection\n");

#endif
		handle_client(i, ftp_ctrl_s, ftp_data_s);
		disconnect(i);
		close(i);
#ifdef DEBUG
		printf("closed connection\n");
#endif
		break;
		
	    case SOCK_CLOSED:
		close(i);
		socket(i, Sn_MR_TCP, HTTP_PORT, 0);
		break;
		
	    case SOCK_CLOSE_WAIT:
		disconnect(i);
		break;
		
	    case SOCK_INIT:
		listen(i);
		break;
		
	} /* switch */
	
    } /* for */
}

int Httpd::handle_client(int socket, int ftp_ctrl_s, int ftp_data_s)
{
/* read from the socket
 * if it is a GET:
 *      open requested file
 *      if no file name given:
 *          assume index.html
 *      transmit the HTTP header to the browser
 *      transmit the file to the browser
 * else:
 *      tell client the method is not supported
 */

    char buffer[BUFFSIZE+1];
    char method[10];  
    char path[64];
    char real_path[64];
    int len, ret, temp, htmlDoc;
    RESULT res;

    at91_pio_write (&PIOB_DESC, LED1, LED_ON );
    
    memset(path, 0, 64);
    memset(real_path, 0, 64);
    memset(buffer, 0, BUFFSIZE+1);

    ret = recv(socket, (uint8 *)buffer, BUFFSIZE);
    if (ret <= 0) {
	perror("read error");
	exit(EXIT_FAILURE);
    }
    if (ret > 0 && ret < BUFFSIZE)
	buffer[ret] = 0; /* append null terminator */

    ret = sscanf(buffer, "%s%s", method, path);
    
    if (ret != 2)
    {
	send_status(socket, HTTP_BAD_REQUEST, "Bad Request");
	return 1;
    }

    if (strncmp(method, "GET", 4) != 0){
	send_status(socket, HTTP_NOT_IMPLEMENTED, "Not Implemented");
	return 1;
    }
	
    if (strncmp(path, "/", 2) == 0)
    {
	sprintf(path, "/index.htm");
    }
    else if (strncmp(path, "/listImages", 12) == 0)
    {
	/*get and print HTML directory listing */
	send_dir_list(socket, ftp_ctrl_s, ftp_data_s, IMAGE_DIR);
	return 0;
    }
    else if (strncmp(path, "/secureOff", 11) == 0)
    {
	at91_extirq_close(&IRQ1_DESC);

	send_status(socket, HTTP_OK, "Turned off Secure Mode");
	return 0;
    }
    else if (strncmp(path, "/secureOn", 10) == 0)
    {
	
	at91_extirq_open(&IRQ1_DESC, //depending on which IRQ we use
	    5, //priority
	    AIC_SRCTYPE_EXT_POSITIVE_EDGE, //trigger on rising edge
	    c_handler //our interrupt service routine
	    );
	
	send_status(socket, HTTP_OK, "Turned on Secure Mode");
	return 0;
    }
    else if (strncmp(path, "/getPicture", 12) == 0)
    {
	camera.takePictures(1);
	send_status(socket, HTTP_OK, "Successfully Took Picture");
	return 0;
    }

    sprintf(real_path, "/SmartHome/www%s", path);
    
    /* some debugging code */
    if((temp = getSn_SSR(ftp_ctrl_s)) != SOCK_CLOSED)
    {
#ifdef DEBUG
	printf("ftp_ctrl_s (%d) in unexpected state 0x%x\n", ftp_ctrl_s, temp);
#endif
	disconnect(ftp_ctrl_s);
	close(ftp_ctrl_s);
	

    }
	
    if ((temp = getSn_SSR(ftp_data_s)) != SOCK_CLOSED)
    {
#ifdef DEBUG
	printf("ftp_ctrl_s (%d) in unexpected state %x\n", ftp_ctrl_s, temp);
#endif
	close(ftp_ctrl_s);

    }

   
	
    if((res = ftp_client.ftp_open(ftp_ctrl_s, ftp_data_s, &real_path[1], FTP_PASSIVE,
	    READ)) != FTP_SUCCESS) /* '&path[1]' strips first '/' */
    {
	switch (res)
	{
	    case FTP_READY_FAILED:
#ifdef DEBUG
		printf("ftp ready failed\n");
#endif
		break;

	    case FTP_USER_FAILED:
#ifdef DEBUG
		printf("ftp username failed\n");

#endif
		break;

	    case FTP_PASS_FAILED:
#ifdef DEBUG
		printf("ftp password failed\n");

#endif
		send_status(socket, 401, "Unauthorized");
		break;

	    case FTP_PASV_FAILED:
#ifdef DEBUG
		printf("ftp passive mode failed\n");

#endif
		break;

	    case FTP_OPEN_FAILED:
#ifdef DEBUG
		printf("ftp open failed\n");

#endif
		send_status(socket, 404, "Not Found");
		break;

	}
	
	disconnect(ftp_ctrl_s);
	close(ftp_ctrl_s);
	at91_pio_write (&PIOB_DESC, LED3, LED_OFF);
	at91_pio_write (&PIOB_DESC, LED2, LED_OFF);
	return 1;
    }

#ifdef DEBUG
    printf("Sn_SSR(ftp_data_s) = %x\n", getSn_SSR(ftp_data_s));
    printf("Sn_SSR(ftp_ctrl_s) = %x\n", getSn_SSR(ftp_ctrl_s));
    
    printf("sending header\n");

#endif
    
    send_header(socket, HTTP_OK, "OK", get_mimetype(path));
    htmlDoc = strcmp(get_mimetype(path), "text/html") == 0 ? TRUE : FALSE;

    if (htmlDoc)
	decode_send(socket, ftp_data_s);
    else
    {
	memset(buffer, 0, BUFFSIZE+1);
#ifdef DEBUG
	printf("sending file\n");

#endif
	len = getSn_RX_RSR(ftp_data_s);
	if (len > BUFFSIZE)
	    len = BUFFSIZE;
#ifdef DEBUG
	printf("len = %d\n", len);

#endif
	while (len > 0) 
	{
	    ret = recv(ftp_data_s, (uint8 *)buffer, len);

#ifdef DEBUG
	    printf("ret = %d\n len = %d\n", ret, len);
	    //OSTimeDly(OS_TICKS_PER_SEC/20);
#else
	    OSTimeDly(OS_TICKS_PER_SEC/20);
#endif

	    send_all(socket, (uint8 *)buffer, ret);

	    len = getSn_RX_RSR(ftp_data_s);
	    if (len > BUFFSIZE)
		len = BUFFSIZE;
	    memset(buffer, 0, BUFFSIZE+1);
	}
    }

    disconnect(ftp_data_s);
    close(ftp_data_s);

    disconnect(ftp_ctrl_s);
    close(ftp_ctrl_s);

    at91_pio_write (&PIOB_DESC, LED1, LED_OFF );
   
    return 0;

} /* handle_client */

void Httpd::send_dir_list(int http_s, int ftp_ctrl_s, int ftp_data_s, char * dir_path)
{
    char buffer[BUFFSIZE];
    char parsed_buff[BUFFSIZE];

    memset(buffer, 0, BUFFSIZE);
    memset(parsed_buff, 0, BUFFSIZE);
    
    ftp_client.get_dir_list(ftp_ctrl_s, ftp_data_s, dir_path, buffer);
    
    parse_list(buffer, parsed_buff);

    send_header(http_s, HTTP_OK, "OK", "text/html");
    send_all(http_s, (uint8*)parsed_buff, strlen(parsed_buff));
  
}/* send_dir_list */


void Httpd::parse_list(char * unparsed, char * parsed_start)
{
    /* example list format:
     * /SmartHome/www/img/image0.jpg\r\n
     * /SmartHome/www/img/image1.jpg\r\n
     * /SmartHome/www/img/image2.jpg\r\n
     * /SmartHome/www/img/image3.jpg\r\n
     * /SmartHome/www/img/image4.jpg\r\n
     */

    char * parsed = parsed_start;
    char line[128];
    char * slash_pos; /* position of the last slash */
    int ret;
    
    char * end_unparsed;

    memset(line, 0, 128);

    end_unparsed = unparsed + strlen(unparsed);

    while(unparsed < end_unparsed)
    {
        sscanf(unparsed, "%s", line);
        unparsed += strlen(line) + 2;

        slash_pos = strrchr(line, '/') + 1;

        ret = sprintf(parsed, "<p><a href=\"/img/%s\">%s</a></p>\n", slash_pos, slash_pos);
        parsed+=ret;
        memset(line, 0, 128);
    }

}/* parse_list */

void Httpd::send_status(int socket, int status, char* desc) 
{   
    char buffer [256];

    send_header(socket, status, desc, "text/html");
    sprintf(buffer, "<html><head><title>%d %s</title></head>\n" \
	    "<h4>%d %s</h4>\n"\
	    "</body></html>\n", status, desc, status, desc);

    send_all(socket, (uint8 *)buffer, strlen(buffer));

} /* send_status */

void Httpd::send_header(int socket, int status, char* desc, char *mime_type)
{

    char buffer[256];

    sprintf(buffer, "%s %d %s\r\nContent-Type: %s\r\n\r\n", PROTOCOL, 
	    status, desc, mime_type);
    send_all(socket, (uint8 *)buffer, strlen(buffer));
} /* send_header */


char * Httpd::get_mimetype(char* path)
{
    char * dot_pos; /* position of the last dot */
    
    dot_pos = strrchr(path, '.');

    if (strncmp(dot_pos, ".html", 5) == 0 || 
	    strncmp(dot_pos, ".htm", 4) == 0)
	return "text/html";
    else if (strncmp(dot_pos, ".jpeg", 5) == 0 || 
	    strncmp(dot_pos, ".jpg", 4) == 0)
	return "image/jpeg";
    else 
	return "text/plain"; /* treat everything else as text */
}/* get_mimetype */

void Httpd::decode_send(int http_s, int ftp_data_s)
{
    char buffer[BUFFSIZE];
    char fnName[30];
    char * full_index;
    char * temp;
    char fnReturn[BUFFSIZE];
    int i, j, len, fullLen;
    i = 0;

    memset(buffer, 0, BUFFSIZE);
    memset(fnName, 0, 30);
    memset(fnReturn, 0, BUFFSIZE);

    fullLen = getSn_RX_RSR(ftp_data_s);
    full_index = (char *)malloc(fullLen * sizeof(char));
    memset(full_index, 0, fullLen*sizeof(char));
	    
    len = (fullLen > BUFFSIZE) ? BUFFSIZE : fullLen;

    while (len > 0) 
    {
	recv(ftp_data_s, (uint8 *)buffer, len);
	strncat(full_index, buffer, len); 

	len = getSn_RX_RSR(ftp_data_s);
	if (len > BUFFSIZE)
	    len = BUFFSIZE;
	memset(buffer, 0, BUFFSIZE);
    }

    while(full_index[i] != 0)
    {
        if (strncmp(&full_index[i], "<!--FUNCTIONCALL ",  17) == 0)
        {
            j = i + 17;
            while (strncmp(&full_index[j], "-->", 3) != 0)
                j++;

            strncpy(fnName, &full_index[i + 17], j - i - 17);
	    callFunction(fnName, fnReturn);
            temp = (char *)malloc(fullLen * sizeof(char));
            strncpy(temp, full_index, fullLen);
            fullLen = fullLen  + strlen(fnReturn) - strlen(fnName) - 20;
            full_index = (char *) realloc(full_index, fullLen * sizeof(char));
            memset(full_index, 0, fullLen*sizeof(char));

            strncat(full_index, temp, i);
            strncat(full_index, fnReturn, strlen(fnReturn));
            strncat(full_index, &temp[j + 3], strlen(temp) - j - 3);

	    free(fnReturn);
            free(temp);
        }
        i++;
    }

    i = 0;
    
    while (i < fullLen) 
    {
	memset(buffer, 0, BUFFSIZE);
	strncpy(buffer, &full_index[i], BUFFSIZE);
	send_all(http_s, (uint8 *)buffer, strlen(buffer));
	i += BUFFSIZE;
    }
    
    free(full_index);
}

void Httpd::callFunction(char * fnName, char * fnReturn)
{

    if (strncmp(fnName, "getName", strlen(fnName)) == 0)
    {
	getName(fnReturn);
    }
    /*else if (strncmp(fnName, "getImgArray", strlen(fnName)) == 0)
    {
	getImgArray(fnReturn);
	}*/
    else
    {
	strcpy(fnReturn, "");
    }

}



void Httpd::getName(char * fnReturn)
{
    strcpy(fnReturn, "UR SMARTHOME");
}

//void Httpd::getImgArray(char * fnReturn)
//{
//    int i, max_num;
//    char img_name[64];
//
//    int ftp_ctrl_s = FTP_CTRL_SOCKET_CAMERA;
//    int ftp_data_s = FTP_DATA_SOCKET_CAMERA;
//
//    memset(img_name, 0, 64);
//
//    max_num = ftp_client.get_last_image_num(ftp_ctrl_s, ftp_data_s,
//    "/SmartHome/www/img/");
//
//    max_num = 3;
//
//    
//    for(i = 0; i < max_num; i++)
//    {
//	sprintf(img_name, "imgarray[%d]=\'image%03d.jpg\'\n", i, i);
//	strcat(fnReturn, img_name);
//	
//	memset(img_name, 0, 64);
//    }
//}
